# napari_lfdfiles.py

# Copyright (c) 2021, Christoph Gohlke
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
#    this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.
#
# 3. Neither the name of the copyright holder nor the names of its
#    contributors may be used to endorse or promote products derived from
#    this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

"""Napari plugin for reading files via lfdfiles."""

from napari_plugin_engine import napari_hook_implementation

__version__ = '0.0.2'


@napari_hook_implementation
def napari_get_reader(path):
    if isinstance(path, str) and path.lower().endswith(
        (
            '.v3draw',
            '.flif',
            '.ccp4',
            '.ifli',
            '.ifi',
            '.map',
            '.pic',
            '.vpl',
            '.vpp',
            '.pal',            
            '.out',
            '.int',
            '.phs',
            '.mod',
            '.b64',
            '.i64',
            '.z64',
            '.r64',
            '.cyl',
            '.bhz',
            '.b&h',
            '.i16',
            '.db2',
        )
    ):
        return reader


def reader(path):
    import lfdfiles

    with lfdfiles.LfdFile(path) as lfd:
        data = lfd.asarray()
    return [(data, {}, 'image')]
